@@ -8,10 +8,11 @@ import delta_lake.const as const
 class TestDataLake:
 
     def __init__(self, spark, storage_account_name, storage_account_access_key, storage_landing, storage_bronze,
-                 input_data_param, mount_data_param, colums_validate_merge_param, new_name, database, target, origin):
+                 storage_silver, input_data_param, mount_data_param, colums_validate_merge_param, new_name, database,
+                 target, origin):
         self.delta_lake=DataLake(spark, storage_account_name, storage_account_access_key, storage_landing,
-                                 storage_bronze, input_data_param, mount_data_param, colums_validate_merge_param,
-                                 new_name, database, target, origin)
+                                 storage_bronze, storage_silver, input_data_param, mount_data_param,
+                                 colums_validate_merge_param, new_name, database, target, origin)
 
     def test_initialize_config_storage(self):
         self.delta_lake.initialize_config_storage()
